#/bin/sh

if [ -n $1 ]; then
	cd $1
fi

quilt series | tac | while read file; do
	case $file in
		patches/*)
			;;
		*)
			file="patches/$file"
			;;
	esac

	patch -R -p1 < $file;
done
quilt push -a
